<?php

/*---------------------------------------------------*
 *  Dinh Quoc Han @ 2014
 *---------------------------------------------------*/
class DQH_metaboxes {

    /**
     * Hook into the appropriate actions when the class is constructed.
     */
    public function __construct() {
        add_action( 'add_meta_boxes', array( $this, 'add_meta_box' ) );
        add_action( 'save_post', array( $this, 'save' ) );
    }

    /**
     * Adds the meta box container.
     */
    public function add_meta_box( $post_type ) {
            $post_types = array('post');
            if ( in_array( $post_type, $post_types )) {
        add_meta_box(
            'some_meta_box_name'
            ,__( 'Thông tin truyện', 'DQH_theme' )
            ,array( $this, 'render_meta_box_content' )
            ,$post_type
            ,'advanced'
            ,'high'
        );
            }
    }

    /**
     * Save the meta when the post is saved.
     *
     * @param int $post_id The ID of the post being saved.
     */
    public function save( $post_id ) {
    
        /*
         * We need to verify this came from the our screen and with proper authorization,
         * because save_post can be triggered at other times.
         */

        // Check if our nonce is set.
        if ( ! isset( $_POST['DQH_metaboxes'] ) )
            return $post_id;

        $nonce = $_POST['DQH_metaboxes'];

        // Verify that the nonce is valid.
        if ( ! wp_verify_nonce( $nonce, 'DQH_metaboxes_box' ) )
            return $post_id;

        // If this is an autosave, our form has not been submitted,
                //     so we don't want to do anything.
        if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) 
            return $post_id;

        // Check the user's permissions.
        if ( 'page' == $_POST['post_type'] ) {

            if ( ! current_user_can( 'edit_page', $post_id ) )
                return $post_id;
    
        } else {

            if ( ! current_user_can( 'edit_post', $post_id ) )
                return $post_id;
        }

        /* OK, its safe for us to save the data now. */

        update_post_meta( $post_id, 'e_author', $_POST['e_author'] );
        update_post_meta( $post_id, 'e_translator', $_POST['e_translator'] );
        update_post_meta( $post_id, 'e_status', $_POST['e_status'] );
        update_post_meta( $post_id, 'e_source', $_POST['e_source'] );
    }


    /**
     * Render Meta Box content.
     *
     * @param WP_Post $post The post object.
     */
    public function render_meta_box_content( $post ) {
    
        // Add an nonce field so we can check for it later.
        wp_nonce_field( 'DQH_metaboxes_box', 'DQH_metaboxes' );

        // Use get_post_meta to retrieve an existing value from the database.
        $e_author = get_post_meta( $post->ID, 'e_author', true );
        $e_translator = get_post_meta( $post->ID, 'e_translator', true );
        $e_status = get_post_meta( $post->ID, 'e_status', true );
        $e_source = get_post_meta( $post->ID, 'e_source', true );

        // Display the form, using the current value.
        ?>
        <table>
            <tbody>
                <tr>
                    <td><label for="e_author">Tác giả</label></td>
                    <td><input type="text" id="e_author" name="e_author" value="<?php echo esc_attr( $e_author ); ?>" style="width: 100%;"></td>
                </tr>
                <tr>
                    <td><label for="e_translator">Nhóm dịch</label></td>
                    <td><input type="text" id="e_translator" name="e_translator" value="<?php echo esc_attr( $e_translator ); ?>" style="width: 100%;"></td>
                </tr>
                <tr>
                    <td><label for="e_status">Tình trạng</label></td>
                    <td><select id="e_status" name="e_status">
                        <option value="Đang cập nhật" <?php echo (esc_attr( $e_status ) == 'Đang cập nhật') ? 'selected' : ''; ?>>Đang cập nhật</option>
                        <option value="Đã hoàn thành" <?php echo (esc_attr( $e_status ) == 'Đã hoàn thành') ? 'selected' : ''; ?>>Đã hoàn thành</option>
                        <option value="Ngừng cập nhật" <?php echo (esc_attr( $e_status ) == 'Ngừng cập nhật') ? 'selected' : ''; ?>>Ngừng cập nhật</option>
                    </select></td>
                </tr>
                <tr>
                    <td><label for="e_source">Nguồn</label></td>
                    <td><input type="text" id="e_source" name="e_source" value="<?php echo esc_attr( $e_source ); ?>" style="width: 100%;"></td>
                </tr>
            </tbody>
        </table>
        <p>Để trống mặc định sẽ là: <em>Đang cập nhật...</em></p>
<?php
    }
}

new DQH_metaboxes;

/*---------------------------------------------------*
 *  Dinh Quoc Han @ 2014
 *---------------------------------------------------*/